Actions, Resources, and Condition Keys for Amazon CodeGuru Reviewer - AWS Identity and Access Management
Keywords: IAM,AWS Identity and Access Management,IAM user,user,IAM group,group,IAM role,role,permission policy,trust policy,policy,access key,password

Did this page help you? - Yes

Thanks for letting us know we're doing a good job!

If you've got a moment, please tell us what we did right so we can do more of it.

Did this page help you? - No

Thanks for letting us know this page needs work. We're sorry we let you down.

If you've got a moment, please tell us how we can make the documentation better.

# Actions, Resources, and Condition Keys for Amazon CodeGuru Reviewer

Amazon CodeGuru Reviewer (service prefix: `codeguru-reviewer` ) provides the following service-specific resources, actions, and condition context keys for use in IAM permission policies.

References:

- Learn how to configure this service .

- View a list of the API operations available for this service .

- Learn how to secure this service and its resources by using IAM permission policies.

Topics

- Actions Defined by Amazon CodeGuru Reviewer
- Resource Types Defined by Amazon CodeGuru Reviewer
- Condition Keys for Amazon CodeGuru Reviewer

## Actions Defined by Amazon CodeGuru Reviewer

You can specify the following actions in the `Action` element of an IAM policy statement. Use policies to grant permissions to perform an operation in AWS. When you use an action in a policy, you usually allow or deny access to the API operation or CLI command with the same name. However, in some cases, a single action controls access to more than one operation. Alternatively, some operations require several different actions.

The Resource Types column indicates whether each action supports resource-level permissions. If there is no value for this column, you must specify all resources ("*") in the `Resource` element of your policy statement. If the column includes a resource type, then you can specify an ARN of that type in a statement with that action. Required resources are indicated in the table with an asterisk (*). If you specify a resource-level permission ARN in a statement using this action, then it must be of this type. Some actions support multiple resource types. If the resource type is optional (not indicated as required), then you can choose to use one but not the other.

For details about the columns in the following table, see The Actions Table .

Actions | Description | Access Level | Resource Types (*required) | Condition Keys | Dependent Actions
--- | --- | --- | --- | --- | ---
AssociateRepository | Grants permission to associates a repository with Amazon CodeGuru Reviewer. | Write | repository |  | codecommit:ListRepositories codecommit:TagResource events:PutRule events:PutTargets iam:CreateServiceLinkedRole
CreateConnectionToken [permission only] | Grants permission to perform webbased oauth handshake for 3rd party providers. | Read |  |  |
DescribeRepositoryAssociation | Grants permission to describe a repository association. | Read |  |  |
DisassociateRepository | Grants permission to disassociate a repository with Amazon CodeGuru Reviewer. | Write | association* |  | codecommit:UntagResource events:DeleteRule events:RemoveTargets
GetMetricsData [permission only] | Grants permission to view pull request metrics in console. | Read |  |  |
ListRepositoryAssociations | Grants permission to list summary of repository associations. | List |  |  |
ListThirdPartyRepositories [permission only] | Grants permission to list 3rd party providers repositories in console. | Read |  |  |

## Resource Types Defined by Amazon CodeGuru Reviewer

The following resource types are defined by this service and can be used in the `Resource` element of IAM permission policy statements. Each action in the Actions table identifies the resource types that can be specified with that action. A resource type can also define which condition keys you can include in a policy. These keys are displayed in the last column of the table. For details about the columns in the following table, see The Resource Types Table .

Resource Types | ARN | Condition Keys
--- | --- | ---
association | `arn:$ { Partition}:codeguru-reviewer::$ { Account}:association:$ { ResourceId}` |
repository | `arn:$ { Partition}:codecommit:$ { Region}:$ { Account}:$ { RepositoryName}` | aws:ResourceTag/${TagKey}

## Condition Keys for Amazon CodeGuru Reviewer

Amazon CodeGuru Reviewer defines the following condition keys that can be used in the `Condition` element of an IAM policy. You can use these keys to further refine the conditions under which the policy statement applies. For details about the columns in the following table, see The Condition Keys Table .

To view the global condition keys that are available to all services, see Available Global Condition Keys in the IAM Policy Reference .

Condition Keys | Description | Type
--- | --- | ---
aws:ResourceTag/$ { TagKey} | Filters actions based on tag key-value pairs attached to the resource | String